/*
 * Copyright (c) 2014 Citrix Systems, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdarg.h>
#include <stdio.h>
#include <syslog.h>
#include "logging.h"

void logging_set_prefix(const char *ident)
{
    closelog();
    openlog(ident, LOG_NOWAIT | LOG_PID, LOG_DAEMON);
}

static inline void __syslog_vfprintf(const char *format, va_list ap)
{
    vsyslog(LOG_DAEMON | LOG_NOTICE, format, ap);
}

int qemu_log_vfprintf(FILE *stream, const char *format, va_list ap)
{
    __syslog_vfprintf(format, ap);

    return 0;
}

int qemu_log_printf(const char *format, ...)
{
    va_list ap;

    va_start(ap, format);
    __syslog_vfprintf(format, ap);

    return 0;
}

int qemu_log_fprintf(FILE *stream, const char *format, ...)
{
    va_list ap;

    va_start(ap, format);
    __syslog_vfprintf(format, ap);

    return 0;
}
